@@ -328,7 +328,7 @@ class Pod(NamespacedResource):
     def to_dict(self) -> None:
         super().to_dict()
 
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not all([
                 self.containers,
             ]):
