@@ -94,7 +94,7 @@ class DSCInitialization(Resource):
     def to_dict(self) -> None:
         super().to_dict()
 
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not all([
                 self.applications_namespace,
             ]):
@@ -103,7 +103,7 @@ class DSCInitialization(Resource):
             self.res["spec"] = {}
             _spec = self.res["spec"]
 
-            self.res["applicationsNamespace"] = self.applications_namespace
+            _spec["applicationsNamespace"] = self.applications_namespace
 
             if self.dev_flags:
                 _spec["devFlags"] = self.dev_flags
